odk_get_data: ODK get data

Description Usage Arguments Value

View source: R/odk_get_data.R

Description

Retrieve data from the ODK server, parse, organize, and return as dataframes

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
14
15
16
odk_get_data(
  url = "https://bohemia.systems",
  id = "recon",
  id2 = NULL,
  unknown_id2 = FALSE,
  uuids = NULL,
  exclude_uuids = NULL,
  user = NULL,
  password = NULL,
  widen = TRUE,
  pre_auth = FALSE,
  use_data_id = FALSE,
  sleeper = 0.25,
  use_progress_bar = TRUE,
  chunk_size = 1000
)

Arguments

url

The URL of the ODK Aggregate server, default being https://bohemia.systems, without a trailing dash

id

The primary id of the form

id2

The secondary id of the form

unknown_id2

Set to TRUE only if the id2 is unknown. If it is known to be the same as id, set to FALSE. If it is known to be different from id, and is known, set to FALSE and make the id2 argument non-null.

uuids

The uuid(s) (including the "uuid:" prefix) of the particular submission(s) to be retrieved. If NULL (the default), all uuids available will be retrieved

exclude_uuids

The uuid(s) to exclude from retrieval. If NULL (the default), no uuids will be excluded

user

The ODK Aggregate username

password

The ODK Aggregate password

widen

Whether to widen

use_data_id

Whether to substitute the id2 field with "data" in the submission retrieval URL

sleeper

How long to sleep between requests (seconds)

use_progress_bar

Whether to show a progress bar instead of messages for each form

chunk_size

The chunk size for pagination

pre-auth

Pre-authenticate (needed for Manhica server)

Value

A list of dataframes


databrew/saint documentation built on May 13, 2021, 10:56 a.m.