Description Usage Arguments Value
Retrieve data from the ODK server, parse, organize, and return as dataframes
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 |
url |
The URL of the ODK Aggregate server, default being https://bohemia.systems, without a trailing dash |
id |
The primary id of the form |
id2 |
The secondary id of the form |
unknown_id2 |
Set to TRUE only if the id2 is unknown. If it is known to be the same as id, set to FALSE. If it is known to be different from id, and is known, set to FALSE and make the id2 argument non-null. |
uuids |
The uuid(s) (including the "uuid:" prefix) of the particular submission(s) to be retrieved. If NULL (the default), all uuids available will be retrieved |
exclude_uuids |
The uuid(s) to exclude from retrieval. If NULL (the default), no uuids will be excluded |
user |
The ODK Aggregate username |
password |
The ODK Aggregate password |
widen |
Whether to widen |
use_data_id |
Whether to substitute the id2 field with "data" in the submission retrieval URL |
sleeper |
How long to sleep between requests (seconds) |
use_progress_bar |
Whether to show a progress bar instead of messages for each form |
chunk_size |
The chunk size for pagination |
pre-auth |
Pre-authenticate (needed for Manhica server) |
A list of dataframes
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.